@@ -32,6 +32,9 @@ export default class EsDomain extends aux.multipleClasses(EsLookup,EsObjectAcces
         this.mdb=new EsModelDatabase(esInstance,eventBroker);
         this.mdbAccessor=new EsMdbAccessor(this);
         this.cmdRunner=new EsCmdRunner(this);
+
+        //initialize utils
+        this.utils.init()
     }
 
     getEoqDomain(){
