@@ -20,7 +20,7 @@ except ImportError:
 
 import __main__
 
-__version__ = '0.2.10'
+__version__ = '0.2.11'
 
 DEFAULT_PATH='./'
 DEFAULT_HOST=socket.gethostname()
@@ -53,7 +53,7 @@ class EoqConfiguration:
         self.backup=0 # backups are disabled by default
         self.backupDir='./backup'
         self.logDir='./log'
-        self.logToFile=1 # loggint to file is enabled by default
+        self.logToFile=1 # logging to file is enabled by default
         self.logToConsole=0 # logging to console is disabled by default
         self.autosave=5.0 # the timeout after which autosave is triggered
         self.trackFileChanges=0 # whether tracking of changes on the filesystems is enabled (default:OFF)
@@ -119,9 +119,18 @@ class XGEEApp:
             # Configure backup directory
             if self.get_conf_parameter('eoq/backup') is not None:
                 self.eoqConfiguration.backupDir=localpath+'/'+self.path+str(self.get_conf_parameter('eoq/backup')).lstrip("./")
+                self.eoqConfiguration.backup=1 # backups are enabled if a directory was set
             else:
                 self.eoqConfiguration.backupDir=localpath+'/'+self.path+'backup'
 
+            # option to log to console
+            if self.get_conf_parameter('eoq/consolelog') is not None:
+                self.eoqConfiguration.logToConsole=self.get_conf_parameter('eoq/consolelog')
+
+            # Configure autosave
+            if self.get_conf_parameter('eoq/autosave') is not None:
+                self.eoqConfiguration.autosave=self.get_conf_parameter('eoq/consolelog')
+
     def getName(self):
         return self.name
 
@@ -305,3 +314,4 @@ if __name__ == "__main__":
     
 
 
+
